@@ -14,18 +14,38 @@ Unlike the standard webhooks.decorator, this doesn't
 
 from functools import partial
 
-from .conf import WEBHOOKS_SENDER_CALLABLE
-from ..decorators import base_hook
-from ..hashes import basic_hash_function
 
+from django.conf import settings
+
+from .utils import import_sender_callable
+from webhooks.decorators import base_hook
+from webhooks.hashes import basic_hash_function
+
+WEBHOOKS_SENDER = getattr(settings, "WEBHOOKS_SENDER", "djwebhooks.senders.orm.sender")
+
+# sender_callable is set via settings.WEBHOOKS_SENDER
+sender_callable = import_sender_callable(WEBHOOKS_SENDER)
 
 # This is decorator that does all the lifting.
-# sender_callable is set via settings.py
 hook = partial(
     base_hook,
-    sender_callable=WEBHOOKS_SENDER_CALLABLE,
+    sender_callable=sender_callable,
     hash_function=basic_hash_function
 )
 
+hook.__doc__ = getattr(sender_callable, "doc", "No documentation yet!")
+
+hook.__doc__ = "blarg"
+
 # alias the hook function
 webhook = hook
+
+
+# Make the redis hook work
+# This is decorator that does all the lifting.
+from djwebhooks.senders.redisq import sender as sender_rq
+redis_hook = partial(
+    base_hook,
+    sender_callable=sender_rq,
+    hash_function=basic_hash_function
+)
\ No newline at end of file
